@@ -22,10 +22,17 @@ from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from collective.portlet.relateditems import RelatedItemsMessageFactory as _
 
 # Hardlink to contentleadimage product
-from collective.contentleadimage.config import IMAGE_FIELD_NAME
-from collective.contentleadimage.leadimageprefs import ILeadImagePrefsForm
-from zope.component import getUtility
-from Products.CMFPlone.interfaces import IPloneSiteRoot
+
+try:
+    from collective.contentleadimage.config import IMAGE_FIELD_NAME
+    from collective.contentleadimage.leadimageprefs import ILeadImagePrefsForm
+    from zope.component import getUtility
+    from Products.CMFPlone.interfaces import IPloneSiteRoot
+    LEADIMAGE_EXISTS = True
+except ImportException:
+    LEADIMAGE_EXISTS = False
+    
+
 
 DEFAULT_ALLOWED_TYPES = (
     'News Item',
@@ -162,18 +169,23 @@ class Renderer(base.Renderer):
 
     @property
     def prefs(self):
-        portal = getUtility(IPloneSiteRoot)
-        return ILeadImagePrefsForm(portal)
+        res = ''
+        if LEADIMAGE_EXISTS:
+            print 'prefs called'
+            portal = getUtility(IPloneSiteRoot)
+            res = ILeadImagePrefsForm(portal)
+        return res
     
     #used for the view (relateditems.pt)
     def tag(self, obj, css_class='tileImage'):
+        if LEADIMAGE_EXISTS:
             context = aq_inner(obj)
             field = context.getField(IMAGE_FIELD_NAME)
             if field is not None:
                 if field.get_size(context) != 0:
-                    scale = 'thumb'#self.prefs.desc_scale_name
+                    scale = 'thumb' #self.prefs.desc_scale_name
                     return field.tag(context, scale=scale, css_class=css_class)
-            return ''
+        return ''
     
     def getAllRelatedItemsLink(self):
         portal_state = getMultiAdapter((self.context, self.request),
